<?php
/**
 * Plugin CIBC
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

if (!defined("_ECRIRE_INC_VERSION")) return;

include_spip('inc/cibc_commun');


function formulaires_cibc_config_charger_dist() {

	if (!autoriser('configurer', 'configuration'))
		return false;

	// valeurs actuelles
	$valeurs = cibc_tableau_meta();

	// parametrage par constantes
	foreach ($valeurs AS $cle=>$valeur){
		$constante = cibc_constantes($cle);
		if ($constante!==NULL){
			$valeurs[$cle.'_disabled'] = ' disabled="disabled" ';
		} else {
			$valeurs[$cle.'_disabled'] = '';
		}
		
	}	

	return $valeurs;
}

function formulaires_cibc_config_verifier_dist(){
	$erreurs = array();
        
	if (cibc_constantes('texte')===NULL AND !_request('texte'))
		$erreurs['texte'] =  _T('info_obligatoire');

	if (cibc_constantes('url_savoir')===NULL AND _request('url_savoir') AND !cibc_filtrer_url(_request('url_savoir'),true))
		$erreurs['url_savoir'] =  _T('cibc:erreur_url_savoir');

	if (cibc_constantes('url_refus')===NULL AND _request('url_refus') AND !cibc_filtrer_url(_request('url_refus'),true))
		$erreurs['url_refus'] =  _T('cibc:erreur_url_refus');
		
	if (cibc_constantes('duree_cookie')===NULL AND !_request('duree_cookie'))
		$erreurs['duree_cookie'] =  _T('info_obligatoire');
	
	if (cibc_constantes('duree_cookie')===NULL AND _request('duree_cookie') AND intval(_request('duree_cookie')>395))
		$erreurs['duree_cookie'] =  _T('cibc:erreur_duree_cookie');

	if (cibc_constantes('comportement_desactiver')===NULL AND !in_array(_request('comportement_desactiver'), array('avant','apres','libre')))
		$erreurs['comportement_desactiver'] =  _T('cibc:erreur_comportement_desactiver');
		
	if (cibc_constantes('comportement')===NULL AND !in_array(_request('comportement'), array('1','2','3')))
		$erreurs['comportement'] =  _T('cibc:erreur_comportement');

		
	return $erreurs;
}

function formulaires_cibc_config_traiter_dist(){
	$res = array();
        
	// valeurs actuelles
	$cibc_meta = cibc_tableau_meta();
	$ok = false;
	$invalider = false;
	
	if (cibc_constantes('texte')===NULL AND $valeur_saisie = _request('texte')){
		if ($cibc_meta['texte'] != $valeur_saisie)
			$invalider = true;
			
		$cibc_meta['texte'] = $valeur_saisie;
		$ok = true;
	}
	
	if (cibc_constantes('url_savoir')===NULL){
		if (!_request('url_savoir')){
			$cibc_meta['url_savoir'] = '';
		} elseif ($valeur_saisie = cibc_filtrer_url(_request('url_savoir'))){
			if ($cibc_meta['url_savoir'] != $valeur_saisie)
				$invalider = true;
	
			$cibc_meta['url_savoir'] = $valeur_saisie;
			$ok = true;	
		}
	}

	if (cibc_constantes('url_refus')===NULL){	
		if (!_request('url_refus')){
			$cibc_meta['url_refus'] = '';
		} elseif ($valeur_saisie = cibc_filtrer_url(_request('url_refus'))){
			if ($cibc_meta['url_refus'] != $valeur_saisie)
				$invalider = true;
	
			$cibc_meta['url_refus'] = $valeur_saisie;
			$ok = true;	
		}
	}

	if (cibc_constantes('duree_cookie')===NULL AND $valeur_saisie = intval(_request('duree_cookie'))){
		if ($cibc_meta['duree_cookie'] != $valeur_saisie)
			$invalider = true;

		$cibc_meta['duree_cookie'] = $valeur_saisie;
		$ok = true;	
	}

	$valeur_saisie = _request('css');
	if ($valeur_saisie AND cibc_constantes('css')===NULL AND substr($valeur_saisie, 0, 10)=='_css/cibc_' AND find_in_path($valeur_saisie)){
		if ($cibc_meta['css'] != $valeur_saisie)
			$invalider = true;

		$cibc_meta['css'] = $valeur_saisie;
		$ok = true;	
	}

	$valeur_saisie = _request('comportement_desactiver');
	if (cibc_constantes('comportement_desactiver')===NULL AND in_array($valeur_saisie, array('avant','apres','libre'))){
		if ($cibc_meta['comportement_desactiver'] != $valeur_saisie)
			$invalider = true;
		
		$cibc_meta['comportement_desactiver'] = $valeur_saisie;
		$ok = true;	
	}
	
	$valeur_saisie = _request('comportement');
	if (cibc_constantes('comportement')===NULL AND in_array($valeur_saisie, array('1','2','3'))){
		if ($cibc_meta['comportement'] != $valeur_saisie)
			$invalider = true;
		
		$cibc_meta['comportement'] = $valeur_saisie;
		$ok = true;	
	}

	$valeurs = array('bouton_savoir','bouton_accepte','bouton_refus','banniere_si_authentifie');
	
	foreach ($valeurs AS $valeur) {
		if (cibc_constantes($valeur)===NULL){
			if (_request($valeur)=='oui'){
				if ($cibc_meta[$valeur] != 'oui')
					$invalider = true;
				
				$cibc_meta[$valeur] = 'oui';
				$ok = true;	
			} else {
				if ($cibc_meta[$valeur] != '')
					$invalider = true;
	
				$cibc_meta[$valeur] = '';
			}
		}
	}
	
	if ($ok){
		include_spip('inc/meta');
		ecrire_meta('cibc', @serialize($cibc_meta));
		
		if ($invalider){
			include_spip('inc/invalideur');
			suivre_invalideur("1");
		}
	}
	
	$res['message_ok'] = "";
	$res['redirect'] = "";
	
	return $res;	
}


function cibc_filtrer_url($texte, $verif_only=false) {
	$safe = '';
        if (empty($texte)){
            return '';
        }
	$t = trim($texte);
	include_spip('inc/filtres');	
	$t = filtrer_entites($t);
	
	if ($t) {	
		// supprimer les espaces
	    $t = trim(str_replace(' ', '',$t)); 
		
		// interdire les caracteres dangereux
		// limiter à a-zA-Z0-9 et aux slash, deux points, =, &, diese, underscores, tirets, points, point interrogation
		$tableau = array('/',":","=","&",'#',"_",'-','.',',','?');
		$safe = cibc_filtrer_caracteres($t,$tableau,$verif_only);

	    // supprimer les espaces
	    if (!$verif_only)
		    $safe = trim(str_replace(' ', '',$safe )); 
	}
    
   	return $safe;
}


function cibc_filtrer_caracteres($t,$tableau=array(),$verif_only=false) {
	$safe = '';
	$verif = true;
	
	if ($t AND is_array($tableau)){
		
		// supprimer les accents
		include_spip('inc/charsets');
		$tsa = translitteration($t);
		
		$tscs = str_replace($tableau,'',$tsa);
		if (!ctype_alnum($tscs)) {
			$verif = false;

			// passer le cas echeant en iso pour avoir la meme longueur avec ou sans accent en utf-8	
			if ($GLOBALS['meta']['charset'] != 'iso-8859-1')
				$tiso = iconv(strtoupper($GLOBALS['meta']['charset']), "ISO-8859-1", $t);
			else
				$tiso = $t;

			// enlever les caracteres speciaux
			$longueur = strlen($tsa);
		    for ($i = 0; $i < $longueur; $i++){
		    	if (ctype_alnum($tsa[$i]) OR in_array($tsa[$i], $tableau))
		    		$safe .= $tiso[$i];
		    	else
		        	$safe .= ' ';
		    }
			// repasser le cas echeant dans le charset du site
			if ($GLOBALS['meta']['charset'] != 'iso-8859-1')
				$safe = iconv("ISO-8859-1", strtoupper($GLOBALS['meta']['charset']), $safe);
		    
		} else {
			$safe = $t;
		}
	}
		
    if ($verif_only)
    	return $verif;
	
   	return $safe;
}

function cibc_select_css($valeur_actuelle='') {
	$return = '';

	if (!$valeur_actuelle)
		$valeur_actuelle = '_css/cibc_en_bas_fond_noir.css';
			
	if ($f = find_in_path($valeur_actuelle)){
	
	    $return .= '<option value="'.$valeur_actuelle.'" selected="selected">'.cibc_titre_css($valeur_actuelle).'</option>';

	    $tableau = array();
	    $repertoire_css = str_replace($valeur_actuelle,'',$f).'_css';
	    $dossier = opendir($repertoire_css);
	    while ($fichier = readdir($dossier)) {
	      if (substr($fichier, 0, 5)=='cibc_'){
	            $fichier_avec_chemin = "_css/".$fichier;
	            if ($fichier_avec_chemin != $valeur_actuelle)
				    $tableau[] = '<option value="'.$fichier_avec_chemin.'">'.cibc_titre_css($fichier_avec_chemin).'</option>';
	      }
	    }
	    closedir($dossier);
	    sort($tableau);
	    $return .= implode('',$tableau);
	}

	return $return;
}

function cibc_titre_css($fichier='') {
	$return = '';

	if ($fichier){
		$return = strtolower($fichier);
		$return = str_replace(array('_css/cibc_','.css'),'',$return);
		$return = str_replace('_',' ',$return);
		$return = ucfirst($return);
	}
	
	return $return;
}

?>